==> logging-timbre-0.2.8.jar: META-INF/leiningen/com.signal-ai/logging-timbre/project.clj <==
(defproject com.signal-ai/logging-timbre "0.2.8"
  :description "Consistent timbre configuration, with JSON structured logging support"
  :url "http://github.com/signal-ai/signal-logging-timbre"
  :license {:name "EPL-2.0 OR GPL-2.0-or-later WITH Classpath-exception-2.0"
            :url "https://www.eclipse.org/legal/epl-2.0/"}
  :dependencies [[com.taoensso/timbre "5.2.1"]

                 [viesti/timbre-json-appender "0.2.7"]

                 ;; route other logging through slf4j -> timbre                 
                 [com.fzakaria/slf4j-timbre "0.3.21"]

                 [org.slf4j/slf4j-api "1.7.36"]
                 [org.slf4j/jul-to-slf4j "1.7.36"]
                 [org.slf4j/jcl-over-slf4j "1.7.36"]
                 [org.slf4j/log4j-over-slf4j "1.7.36"]
                 [org.slf4j/osgi-over-slf4j "1.7.36"]]
  :exclusions
  [;; Exclude transitive dependencies on all other logging
   ;; implementations, including other SLF4J bridges.
   commons-logging
   log4j
   org.apache.logging.log4j/log4j
   ch.qos.logback/logback-classic
   ch.qos.logback/logback-core
   org.slf4j/simple
   org.slf4j/slf4j-jcl
   org.slf4j/slf4j-nop
   org.slf4j/slf4j-log4j12
   org.slf4j/slf4j-log4j13]

  :profiles {:test {:dependencies [[lambdaisland/kaocha "1.69.1069"]
                                   [lambdaisland/kaocha-junit-xml "0.0.76"]
                                   [lambdaisland/kaocha-cloverage "1.0.75"]

                                   [metosin/jsonista "0.3.6"]

                                   ;; http
                                   [compojure "1.7.0"]
                                   [ring/ring-defaults "0.3.3"]
                                   [ring/ring-mock "0.4.0"]]}}

  :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                     :username :env/clojars_username
                                     :password :env/clojars_token
                                     :sign-releases false}]
                        ["snapshots" {:url "https://clojars.org/repo"
                                      :username :env/clojars_username
                                      :password :env/clojars_token}]]
  :aliases {"test" ["with-profile" "dev,test" "run" "-m" "kaocha.runner"]})

==> logging-timbre-0.2.8-20220727.162545-2.jar: META-INF/leiningen/com.signal-ai/logging-timbre/project.clj <==
(defproject com.signal-ai/logging-timbre "0.2.8-SNAPSHOT"
  :description "Consistent timbre configuration, with JSON structured logging support"
  :url "http://github.com/signal-ai/signal-logging-timbre"
  :license {:name "EPL-2.0 OR GPL-2.0-or-later WITH Classpath-exception-2.0"
            :url "https://www.eclipse.org/legal/epl-2.0/"}
  :dependencies [[com.taoensso/timbre "5.2.1"]

                 [viesti/timbre-json-appender "0.2.7"]

                 ;; route other logging through slf4j -> timbre                 
                 [com.fzakaria/slf4j-timbre "0.3.21"]

                 [org.slf4j/slf4j-api "1.7.36"]
                 [org.slf4j/jul-to-slf4j "1.7.36"]
                 [org.slf4j/jcl-over-slf4j "1.7.36"]
                 [org.slf4j/log4j-over-slf4j "1.7.36"]
                 [org.slf4j/osgi-over-slf4j "1.7.36"]]
  :exclusions
  [;; Exclude transitive dependencies on all other logging
   ;; implementations, including other SLF4J bridges.
   commons-logging
   log4j
   org.apache.logging.log4j/log4j
   ch.qos.logback/logback-classic
   ch.qos.logback/logback-core
   org.slf4j/simple
   org.slf4j/slf4j-jcl
   org.slf4j/slf4j-nop
   org.slf4j/slf4j-log4j12
   org.slf4j/slf4j-log4j13]

  :profiles {:test {:dependencies [[lambdaisland/kaocha "1.69.1069"]
                                   [lambdaisland/kaocha-junit-xml "0.0.76"]
                                   [lambdaisland/kaocha-cloverage "1.0.75"]

                                   [metosin/jsonista "0.3.6"]

                                   ;; http
                                   [compojure "1.7.0"]
                                   [ring/ring-defaults "0.3.3"]
                                   [ring/ring-mock "0.4.0"]]}}

  :deploy-repositories [["releases" {:url "https://clojars.org/repo"
                                     :username :env/clojars_username
                                     :password :env/clojars_token
                                     :sign-releases false}]
                        ["snapshots" {:url "https://clojars.org/repo"
                                      :username :env/clojars_username
                                      :password :env/clojars_token}]]
  :aliases {"test" ["with-profile" "dev,test" "run" "-m" "kaocha.runner"]})
